# nonce

[![pub package](https://img.shields.io/pub/v/nonce.svg)](https://pub.dartlang.org/packages/nonce)

[Nonce] contains a static generator that generates random alphanumeric strings,
and can be constructed as an object containing a generated string.

# Usage

```dart
import 'package:nonce/nonce.dart';
```

## Generator

The static method [generate] can be used to generate random alphanumeric strings;
it has one optional parameter, [length], to specify the length of the generated string.

```dart
print(Nonce.generate()); // Osp54up7WU6P3U97Jz92p9j892n9LP7z
print(Nonce.generate(64)); // LDwpr1H74qm894jbd15Lj63wF5RUL07r4L9XOY7zVMz7fLbBCXa68Y6oPw0N9XgV
```

`generate()` does not rely on Base64 encoding, instead it generates ASCII character codes directly.

## Constructors

[Nonce]'s default constructor constructs a [Nonce] of the specified length; `32` characters by default.

```dart
Nonce();
Nonce(64);
```

### unique

[Nonce]'s [unique] constructor references a global set of every nonce
generated by it, and ensures that every nonce returned by it is unique.

```dart
Nonce.unique();
Nonce.unique(64);
```

### key

The [key] constructor is shorthand to generate a [unique] nonce `16` characters
in length.


```dart
Nonce.key(); // Osp54up7WU6P3U97
```
